@@ -12,12 +12,13 @@
 #' @param ... further arguments passed through, see description of return value
 #'   for details.
 #' @param trms,xlev,grid same as for \code{\link[emmeans]{emm_basis}}.
-#' @param model argument for \code{\link[emmeans]{emmeans}()} and rlated
+#' @param model argument for \code{\link[emmeans]{emmeans}()} and related
 #'   functions that allows to choose on which model the follow-up tests for
-#'   ANOVAs with repeated-measures factors are based. \code{"univariate"} uses
-#'   the \code{aov} model and \code{"multivariate"} uses the \code{lm} model.
-#'   Default given by \code{afex_options("emmeans_mode")}. Multivariate tests
-#'   likely provide a better correction for violations of sphericity.
+#'   ANOVAs with repeated-measures factors are based. \code{"multivariate"} (the
+#'   default) uses the \code{lm} model and \code{"univariate"} uses the
+#'   \code{aov} model. Default given by \code{afex_options("emmeans_mode")}.
+#'   Multivariate tests likely work better for unbalanced data and provide a
+#'   better correction for violations of sphericity.
 #' 
 #' @return
 #' \describe{
@@ -57,8 +58,7 @@
 #' Cramer, A. O. J., van Ravenzwaaij, D., Matzke, D., Steingroever, H., Wetzels,
 #' R., Grasman, R. P. P. P., ... Wagenmakers, E.-J. (2015). Hidden multiplicity
 #' in exploratory multiway ANOVA: Prevalence and remedies.  \emph{Psychonomic
-#' Bulletin & Review}, 1-8.
-#' doi:\href{https://doi.org/10.3758/s13423-015-0913-5}{10.3758/s13423-015-0913-5}
+#' Bulletin & Review}, 1-8. \doi{10.3758/s13423-015-0913-5}
 #' 
 #' @name afex_aov-methods
 #' @importFrom stats p.adjust
@@ -88,7 +88,13 @@ anova.afex_aov <- function(object,
   es <- match.arg(es, c("none", "ges", "pes"), several.ok = TRUE)
   correction <- match.arg(correction, c("GG", "HF", "none"))
   if (inherits(object$Anova, "Anova.mlm")) {
-    tmp <- suppressWarnings(summary(object$Anova, multivariate = FALSE))
+    tmp <- tryCatch(
+      expr = suppressWarnings(summary(object$Anova, multivariate = FALSE)), 
+      error = function(e) 
+        stop("summary.Anova.mlm() failed for 'afex_aov' object.", 
+             "\nPossible reason, car package updated.", 
+             "\nTry refitting model with afex ANOVA function.", call. = FALSE)
+    )              
     t.out <- tmp[["univariate.tests"]]
     #browser()
     #t.out <- cbind(t.out, orig_den_df =  t.out[, "den Df"])
@@ -245,7 +251,7 @@ recover_data.afex_aov = function(object, ...,
                                  model = afex_options("emmeans_model")) {
   model <- match.arg(model, c("univariate", "multivariate"))
   if (model == "univariate" & is.null(object$aov)) {
-    message("Substituting multivariate/lm model, as aov object missing.")
+    message("aov object missing, substituting multivariate/lm model.\nto get univariate tests, refit ANOVA with include_aov = TRUE")
     model <- "multivariate"
   }
   if (model == "univariate") {
